@@ -13,6 +13,7 @@ from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.audit import AuditModel
+from isc_common.progress import Progress
 from kaf_pas.ckk.models.attr_type import Attr_type
 from kaf_pas.kd.models.pathes import Pathes
 
@@ -205,6 +206,8 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
     @staticmethod
     def delete(id, user):
         from isc_common.auth.models.user import User
+        from kaf_pas.ckk.models.item import Item
+        from kaf_pas.ckk.models.item import ItemManager
         from kaf_pas.kd.models.document_attr_cross import Document_attr_cross
         from kaf_pas.kd.models.documents_thumb import Documents_thumb
         from kaf_pas.kd.models.documents_thumb10 import Documents_thumb10
@@ -212,6 +215,7 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
         from kaf_pas.kd.models.lotsman_documents_hierarcy_files import Lotsman_documents_hierarcy_files
         from kaf_pas.kd.models.lotsman_documents_hierarcy_refs import Lotsman_documents_hierarcy_refs
         from kaf_pas.kd.models.uploades_documents import Uploades_documents
+        from kaf_pas.kd.models.documents_history import Documents_history
 
         if not isinstance(user, User):
             raise Exception(f'user  must be a User instance.')
@@ -220,25 +224,32 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
         res = 0
         lotsman_res = 0
 
+        for item in Item.objects.filter(document_id=id):
+            if ItemManager.delete_recursive(item_id=item.id, user=user, delete_lines=True, document=Documents.objects.get(id=id)) == -2:
+                return res, lotsman_res
+
+        for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document_id=id):
+            for item in Item.objects.filter(lotsman_documents_hierarcy=lotsman_documents_hierarcy):
+                if ItemManager.delete_recursive(item_id=item.id, user=user, delete_lines=True, document=lotsman_documents_hierarcy) == 2:
+                    return res, lotsman_res
+
+            Lotsman_documents_hierarcy_refs.objects.filter(child=lotsman_documents_hierarcy).delete()
+            Lotsman_documents_hierarcy_refs.objects.filter(parent=lotsman_documents_hierarcy).delete()
+            lotsman_documents_hierarcy.delete()
+            lotsman_res += 1
+
+        Documents_history.objects.filter(new_document_id=id).delete()
+        Documents_history.objects.filter(old_document_id=id).delete()
         Uploades_documents.objects.filter(document_id=id).delete()
         Documents_thumb.objects.filter(document_id=id).delete()
         Documents_thumb10.objects.filter(document_id=id).delete()
         Document_attr_cross.objects.filter(document_id=id).delete()
 
-        # for item in Item.objects.filter(document_id=id):
-        #     ItemManager.delete_recursive(item_id=item.id, user=user)
-
         Lotsman_documents_hierarcy_files.objects.filter(lotsman_document__document_id=id).delete()
 
         Documents_thumb.objects.filter(lotsman_document__document_id=id).delete()
         Documents_thumb10.objects.filter(lotsman_document__document_id=id).delete()
 
-        for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document_id=id):
-            Lotsman_documents_hierarcy_refs.objects.filter(child=lotsman_documents_hierarcy).delete()
-            Lotsman_documents_hierarcy_refs.objects.filter(parent=lotsman_documents_hierarcy).delete()
-            lotsman_documents_hierarcy.delete()
-            lotsman_res += 1
-
         res += Documents.objects.filter(id=id).delete()[0]
         settings.LOCKS.release('DocumentManager.delete')
         return res, lotsman_res
@@ -255,6 +266,7 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
         user_id = request.user_id
 
         res = 0
+        lotsman_res = 0
         with transaction.atomic():
             for i in range(0, len(ids), 2):
                 id = ids[i]
@@ -262,12 +274,6 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
 
                 if visibleMode != "none":
                     for item in Item.objects.filter(document_id=id):
-                        # Item_refs.objects.filter(child=item).soft_delete(visibleMode=visibleMode)
-                        # Item_refs.objects.filter(parent=item).soft_delete(visibleMode=visibleMode)
-
-                        # Item_line.objects.filter(child=item).soft_delete(visibleMode=visibleMode)
-                        # Item_line.objects.filter(parent=item).soft_delete(visibleMode=visibleMode)
-
                         Item_image_refs.objects.filter(item=item).soft_delete(visibleMode=visibleMode)
 
                         Documents_thumb.objects.filter(lotsman_document__document_id=id).soft_delete(visibleMode=visibleMode)
@@ -277,11 +283,17 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
                         Documents_thumb10.objects.filter(document_id=id).soft_delete(visibleMode=visibleMode)
 
                     Item.objects.filter(document_id=id).soft_delete(visibleMode=visibleMode)
+                    super().filter(id=id).soft_delete(visibleMode=visibleMode)
                     res += super().filter(id=id).soft_delete(visibleMode=visibleMode)
                 else:
-                    res += DocumentManager.delete(id, User.objects.get(id=user_id))
-        refresh_mat_view('kd_documents_mview')
-        refresh_mat_view('kd_lotsman_documents_hierarcy_mview')
+                    _res, _lotsman_res = DocumentManager.delete(id, User.objects.get(id=user_id))
+                    res += _res
+                    lotsman_res += _lotsman_res
+
+        if res > 0:
+            refresh_mat_view(mat_view_name='kd_documents_mview', progressStack=Progress(user=user_id, id='kd_documents_mview'))
+        if lotsman_res > 0:
+            refresh_mat_view(mat_view_name='kd_lotsman_documents_hierarcy_mview', progressStack=Progress(user=user_id, id='kd_lotsman_documents_hierarcy_mview'))
         return res
 
 
