@@ -197,30 +197,31 @@ class DocumentManagerExt:
                                 else:
                                     logger.debug(f'Created: {child}')
 
-                            Item_refs.objects.get_or_create(parent=parent, child=child)
+                            if parent.id != child.id:
+                                Item_refs.objects.get_or_create(parent=parent, child=child)
 
-                            defaults = dict(
-                                parent=parent,
-                                child=child,
-                                SPC_CLM_FORMAT_id=line_specification.get('SPC_CLM_FORMAT_ID'),
-                                SPC_CLM_ZONE_id=line_specification.get('SPC_CLM_ZONE_ID'),
-                                SPC_CLM_POS_id=line_specification.get('SPC_CLM_POS_ID'),
-                                SPC_CLM_MARK_id=line_specification.get('SPC_CLM_MARK_ID'),
-                                SPC_CLM_NAME_id=line_specification.get('SPC_CLM_NAME_ID'),
-                                SPC_CLM_COUNT_id=line_specification.get('SPC_CLM_COUNT_ID'),
-                                SPC_CLM_NOTE_id=line_specification.get('SPC_CLM_NOTE_ID'),
-                                SPC_CLM_MASSA_id=line_specification.get('SPC_CLM_MASSA_ID'),
-                                SPC_CLM_MATERIAL_id=line_specification.get('SPC_CLM_MATERIAL_ID'),
-                                SPC_CLM_USER_id=line_specification.get('SPC_CLM_USER_ID'),
-                                SPC_CLM_KOD_id=line_specification.get('SPC_CLM_KOD_ID'),
-                                SPC_CLM_FACTORY_id=line_specification.get('SPC_CLM_FACTORY_ID'),
+                                defaults = dict(
+                                    parent=parent,
+                                    child=child,
+                                    SPC_CLM_FORMAT_id=line_specification.get('SPC_CLM_FORMAT_ID'),
+                                    SPC_CLM_ZONE_id=line_specification.get('SPC_CLM_ZONE_ID'),
+                                    SPC_CLM_POS_id=line_specification.get('SPC_CLM_POS_ID'),
+                                    SPC_CLM_MARK_id=line_specification.get('SPC_CLM_MARK_ID'),
+                                    SPC_CLM_NAME_id=line_specification.get('SPC_CLM_NAME_ID'),
+                                    SPC_CLM_COUNT_id=line_specification.get('SPC_CLM_COUNT_ID'),
+                                    SPC_CLM_NOTE_id=line_specification.get('SPC_CLM_NOTE_ID'),
+                                    SPC_CLM_MASSA_id=line_specification.get('SPC_CLM_MASSA_ID'),
+                                    SPC_CLM_MATERIAL_id=line_specification.get('SPC_CLM_MATERIAL_ID'),
+                                    SPC_CLM_USER_id=line_specification.get('SPC_CLM_USER_ID'),
+                                    SPC_CLM_KOD_id=line_specification.get('SPC_CLM_KOD_ID'),
+                                    SPC_CLM_FACTORY_id=line_specification.get('SPC_CLM_FACTORY_ID'),
 
-                                section=line_specification.get('section'),
-                                subsection=line_specification.get('subsection'),
-                            )
+                                    section=line_specification.get('section'),
+                                    subsection=line_specification.get('subsection'),
+                                )
 
-                            item_line, _ = Item_line.objects.get_or_create(parent=parent, child=child, defaults=defaults)
-                            # print(f'Create Item_line: {item_line}')
+                                item_line, _ = Item_line.objects.get_or_create(parent=parent, child=child, defaults=defaults)
+                                # print(f'Create Item_line: {item_line}')
 
                 else:
                     pass
